@@ -1,4 +1,5 @@
 import os
+
 import torch
 
 from s3prl.util.download import _urls_to_filepaths
@@ -33,7 +34,9 @@ def data2vec_base_960(refresh=False, *args, **kwargs):
     The Base model
         refresh (bool): whether to download ckpt/config again if existed
     """
-    kwargs["ckpt"] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/audio_base_ls.pt"
+    kwargs[
+        "ckpt"
+    ] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/audio_base_ls.pt"
     return data2vec_custom(refresh=refresh, *args, **kwargs)
 
 
@@ -42,5 +45,7 @@ def data2vec_large_ll60k(refresh=False, *args, **kwargs):
     The Large model trained on Libri-light 60k hours of data
         refresh (bool): whether to download ckpt/config again if existed
     """
-    kwargs["ckpt"] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vox_pretrained.pt"
+    kwargs[
+        "ckpt"
+    ] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vox_pretrained.pt"
     return data2vec_custom(refresh=refresh, *args, **kwargs)
