@@ -51,7 +51,9 @@ def vq_wav2vec_gumbel(refresh=False, legacy=False, **kwargs):
     """
     kwargs["ckpt"] = "https://dl.fbaipublicfiles.com/fairseq/wav2vec/vq-wav2vec.pt"
     if not legacy:
-        kwargs["ckpt"] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vq-wav2vec.pt"
+        kwargs[
+            "ckpt"
+        ] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vq-wav2vec.pt"
     return vq_wav2vec_custom(refresh=refresh, legacy=legacy, **kwargs)
 
 
@@ -64,5 +66,7 @@ def vq_wav2vec_kmeans(refresh=False, legacy=False, **kwargs):
         "ckpt"
     ] = "https://dl.fbaipublicfiles.com/fairseq/wav2vec/vq-wav2vec_kmeans.pt"
     if not legacy:
-        kwargs["ckpt"] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vq-wav2vec_kmeans.pt"
+        kwargs[
+            "ckpt"
+        ] = "https://huggingface.co/s3prl/converted_ckpts/resolve/main/vq-wav2vec_kmeans.pt"
     return vq_wav2vec_custom(refresh=refresh, legacy=legacy, **kwargs)
